@@ -24,7 +24,8 @@
 
 
 
-score_test_tnarpq_j <- function(supLM, b, y, W, p, d, Z = NULL, J = 499, gama_L = NULL, gama_U = NULL, tol = 1e-9, ncores = 1) {
+score_test_tnarpq_j <- function(supLM, b, y, W, p, d, Z = NULL, J = 499, gama_L = NULL, gama_U = NULL,
+                                tol = 1e-9, ncores = 1, seed = NULL) {
 
  if ( min(W) < 0 ) {
     stop('The adjacency matrix W contains negative values.')
@@ -73,7 +74,7 @@ score_test_tnarpq_j <- function(supLM, b, y, W, p, d, Z = NULL, J = 499, gama_L
     gama_U <- g[2]
   }
 
-  msn <- Rfast::matrnorm(TT, J)
+  msn <- Rfast::matrnorm(TT, J, seed = seed)
   rows <- rep( (p + 1):TT, each = N )
   msn <- msn[rows, ]
   k <- rep( 1:c(TT - p), each = N )
@@ -114,8 +115,8 @@ score_test_tnarpq_j <- function(supLM, b, y, W, p, d, Z = NULL, J = 499, gama_L
     parallel::stopCluster(cl)
     gamaj <- mod[, 1]
     supLMj <- mod[, 2]
+    names(gamaj) <- names(supLMj) <- NULL
     pval <- mod[, 3]
-
   }
 
   pJ <- sum(pval) / J
